@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import warn_explicit
 
 
-__version__ = '2.1.15'
+__version__ = '2.1.16'
 
 if os.environ.get('SERVER_SOFTWARE') is not None:
     # Google App Engine information
@@ -91,10 +91,12 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'controversial':       'controversial/',
                  'del':                 'api/del/',
                  'deleteflair':         'api/deleteflair',
+                 'delete_redditor':     'api/delete_user',
                  'delete_sr_header':    'r/%s/api/delete_sr_header',
                  'delete_sr_image':     'r/%s/api/delete_sr_img',
                  'distinguish':         'api/distinguish/',
                  'domain':              'domain/%s/',
+                 'duplicates':          'duplicates/%s/',
                  'edit':                'api/editusertext/',
                  'feedback':            'api/feedback/',
                  'flair':               'api/flair/',
@@ -410,7 +412,8 @@ class BaseReddit(object):
     @decorators.oauth_generator
     def get_content(self, url, params=None, limit=0, place_holder=None,
                     root_field='data', thing_field='children',
-                    after_field='after', _use_oauth=False):
+                    after_field='after', _use_oauth=False,
+                    object_filter=None):
         """A generator method to return reddit content from a URL.
 
         Starts at the initial url, and fetches content using the `after`
@@ -437,6 +440,11 @@ class BaseReddit(object):
             contains the list of things. Most objects use 'children'.
         :param after_field: indicates the field which holds the after item
             element
+        :param object_filter: if set to an integer value, fetch content from
+            the corresponding list index in the JSON response. For example
+            the JSON response for submission duplicates is a list of objects,
+            and the object we want to fetch from is at index 1. So we set
+            object_filter=1 to filter out the other useless list elements.
         :type place_holder: a string corresponding to a reddit base36 id
             without prefix, e.g. 'asdfasdf'
         :returns: a list of reddit content, of type Subreddit, Comment,
@@ -461,6 +469,8 @@ class BaseReddit(object):
                 self._use_oauth = _use_oauth  # pylint: disable-msg=W0201
             try:
                 page_data = self.request_json(url, params=params)
+                if object_filter:
+                    page_data = page_data[object_filter]
             finally:  # Restore _use_oauth value
                 if _use_oauth:
                     self._use_oauth = False  # pylint: disable-msg=W0201
@@ -1104,6 +1114,24 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         self.http.cookies.clear()
         self.user = None
 
+    def delete(self, password, message=""):
+        """Delete the currently authenticated redditor. WARNING!
+
+        This action is IRREVERSIBLE. Use only if you're okay with NEVER
+        accessing this reddit account again.
+
+        :param password: password for currently authenticated account
+        :param message: optional 'reason for deletion' message.
+        :returns: json response from the server.
+
+        """
+
+        data = {'user': self.user.name,
+                'passwd': password,
+                'delete_message': message,
+                'confirm': True}
+        return self.request_json(self.config['delete_redditor'], data=data)
+
     def edit_wiki_page(self, subreddit, page, content, reason=''):
         """Create or edit a wiki page with title `page` for `subreddit`.
 
@@ -1215,7 +1243,7 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
 
         This can only be used for assigning your own name flair or link flair
         on your own submissions. For assigning other's flairs using moderator
-        access, check :meth:`.set_flair`
+        access, check :meth:`~praw.__init__.ModFlairMixin.set_flair`
 
         :param item: A string, Subreddit object (for user flair), or
             Submission object (for link flair). If item is a string it will be
@@ -1659,20 +1687,30 @@ class ModOnlyMixin(AuthenticatedReddit):
 
     """
 
-    def _get_userlist_listing(self, url, *args, **kwargs):
+    def _get_userlist(self, url, user_only, *args, **kwargs):
         content = self.get_content(url, *args, **kwargs)
         for data in content:
             user = objects.Redditor(self, data['name'], fetch=False)
-            # pylint: disable-msg=C0103,W0201
             user.id = data['id'].split('_')[1]
-            yield user
+            if user_only:
+                yield user
+            else:
+                data['name'] = user
+                yield data
 
     @decorators.restrict_access(scope=None, mod=True)
-    def get_banned(self, subreddit, *args, **kwargs):
-        """Return a get_content generator of banned users for the subreddit."""
-        return self._get_userlist_listing(self.config['banned'] %
-                                          six.text_type(subreddit),
-                                          *args, **kwargs)
+    def get_banned(self, subreddit, user_only=True, *args, **kwargs):
+        """Return a get_content generator of banned users for the subreddit.
+
+        :param subreddit: The subreddit to get the banned user list for.
+        :param user_only: When False, the generator yields a dictionary of data
+            associated with the server response for that user. In such cases,
+            the Redditor will be in key 'name' (default: True).
+
+        """
+        return self._get_userlist(
+            self.config['banned'] % six.text_type(subreddit), user_only, *args,
+            **kwargs)
 
     def get_contributors(self, subreddit, *args, **kwargs):
         """
@@ -1688,9 +1726,9 @@ class ModOnlyMixin(AuthenticatedReddit):
             # It is necessary to have the 'self' argument as it's needed in
             # restrict_access to determine what class the decorator is
             # operating on.
-            return self._get_userlist_listing(self.config['contributors'] %
-                                              six.text_type(subreddit),
-                                              *args, **kwargs)
+            return self._get_userlist(
+                self.config['contributors'] % six.text_type(subreddit),
+                user_only=True, *args, **kwargs)
 
         if self.is_logged_in():
             if not isinstance(subreddit, objects.Subreddit):
@@ -1786,9 +1824,9 @@ class ModOnlyMixin(AuthenticatedReddit):
     @decorators.restrict_access(scope=None, mod=True)
     def get_wiki_banned(self, subreddit, *args, **kwargs):
         """Return a get_content generator of users banned from the wiki."""
-        return self._get_userlist_listing(self.config['wiki_banned'] %
-                                          six.text_type(subreddit),
-                                          *args, **kwargs)
+        return self._get_userlist(
+            self.config['wiki_banned'] % six.text_type(subreddit),
+            user_only=True, *args, **kwargs)
 
     @decorators.restrict_access(scope=None, mod=True)
     def get_wiki_contributors(self, subreddit, *args, **kwargs):
@@ -1800,9 +1838,9 @@ class ModOnlyMixin(AuthenticatedReddit):
         contributors is all that matters.
 
         """
-        return self._get_userlist_listing(self.config['wiki_contributors'] %
-                                          six.text_type(subreddit),
-                                          *args, **kwargs)
+        return self._get_userlist(
+            self.config['wiki_contributors'] % six.text_type(subreddit),
+            user_only=True, *args, **kwargs)
 
 
 class MySubredditsMixin(AuthenticatedReddit):
