@@ -28,7 +28,7 @@ from functools import partial
 from requests.exceptions import HTTPError
 
 BACKOFF_START = 4  # Minimum number of seconds to sleep during errors
-KEEP_ITEMS = 32  # On each iteration only remember the first # items
+KEEP_ITEMS = 128  # On each iteration only remember the first # items
 
 
 def comment_stream(reddit_session, subreddit, limit=None, verbosity=1):
@@ -45,10 +45,12 @@ def comment_stream(reddit_session, subreddit, limit=None, verbosity=1):
         iteration. When None, fetch all available comments (reddit limits this
         to 1000 (or multiple of 1000 for multi-subreddits). If this number is
         too small, comments may be missed.
-    :param verbosity: A number representing the level of output to receive. 0,
-        no output; 1, provide a count of the number of items processed; 2,
-        output when handled exceptions occur; 3, output some system
-        state. (Default: 1)
+    :param verbosity: A number that controls the amount of output produced to
+        stderr. <= 0: no output; >= 1: output the total number of comments
+        processed and provide the short-term number of comments processed per
+        second; >= 2: output when additional delays are added in order to avoid
+        subsequent unexpected http errors. >= 3: output debugging information
+        regarding the comment stream. (Default: 1)
 
     """
     get_function = partial(reddit_session.get_comments,
@@ -72,10 +74,12 @@ def submission_stream(reddit_session, subreddit, limit=None, verbosity=1):
         is too small, submissions may be missed. Since there isn't a limit to
         the number of submissions that can be retrieved from r/all, the limit
         will be set to 1000 when limit is None.
-    :param verbosity: A number representing the level of output to receive. 0,
-        no output; 1, provide a count of the number of items processed; 2,
-        output when handled exceptions occur; 3, output some system
-        state. (Default: 1)
+    :param verbosity: A number that controls the amount of output produced to
+        stderr. <= 0: no output; >= 1: output the total number of submissions
+        processed and provide the short-term number of submissions processed
+        per second; >= 2: output when additional delays are added in order to
+        avoid subsequent unexpected http errors. >= 3: output debugging
+        information regarding the submission stream. (Default: 1)
 
     """
     if six.text_type(subreddit).lower() == "all":
@@ -92,8 +96,12 @@ def _stream_generator(get_function, reddit_session, limit=None, verbosity=1):
         if verbosity >= level:
             sys.stderr.write(msg + '\n')
 
-    seen = BoundedSet(KEEP_ITEMS * 4)
+    def b36_id(item):
+        return int(item.id, 36)
+
+    seen = BoundedSet(KEEP_ITEMS * 16)
     before = None
+    count = 0  # Count is incremented to bypass the cache
     processed = 0
     backoff = BACKOFF_START
     while True:
@@ -102,30 +110,31 @@ def _stream_generator(get_function, reddit_session, limit=None, verbosity=1):
         start = time.time()
         try:
             i = None
-            gen = enumerate(get_function(limit=limit,
-                                         params={'before': before}))
+            params = {'count': count}
+            count = (count + 1) % 100
+            if before:
+                params['before'] = before
+            gen = enumerate(get_function(limit=limit, params=params))
             for i, item in gen:
-                if item.fullname in seen:
+                if b36_id(item) in seen:
                     if i == 0:
                         if before is not None:
-                            # Either we have a logic problem, or reddit sent us
-                            # out of order data -- log it
+                            # reddit sent us out of order data  -- log it
                             debug('(INFO) {0} already seen with before of {1}'
-                                  .format(item.fullname, before), 2)
-                        # Wait until the request is no longer cached
-                        sleep = (reddit_session.config.cache_timeout,
-                                 'Nothing new. Sleeping for {0} seconds.', 3)
+                                  .format(item.fullname, before), 3)
+                            before = None
                     break
                 if i == 0:  # Always the first item in the generator
                     before = item.fullname
-                items.append(item)
-                processed += 1
+                if b36_id(item) not in seen:
+                    items.append(item)
+                    processed += 1
                 if verbosity >= 1 and processed % 100 == 0:
                     sys.stderr.write(' Items: {0}          \r'
                                      .format(processed))
                     sys.stderr.flush()
                 if i < KEEP_ITEMS:
-                    seen.add(item.fullname)
+                    seen.add(b36_id(item))
             else:  # Generator exhausted
                 if i is None:  # Generator yielded no items
                     assert before is not None
