@@ -419,10 +419,6 @@ class BasicTest(unittest.TestCase, BasicHelper):
         subreddit.title
         self.assertEqual(subreddit.json_dict['display_name'], self.sr)
 
-    #def test_timeout(self):
-    #    self.assertRaises(Timeout, helpers._request, self.r,
-    #                      self.r.config['comments'], timeout=0.001)
-
 
 class CacheTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
@@ -1012,7 +1008,7 @@ class ImageTests(unittest.TestCase, AuthenticatedHelper):
         self.assertTrue(any(name in text_type(x['name']) for x in images_json))
 
 
-class LocalOnlyTest(unittest.TestCase, BasicHelper):
+class LocalOnlyTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
         self.configure()
 
@@ -1041,6 +1037,27 @@ class LocalOnlyTest(unittest.TestCase, BasicHelper):
         self.r.create_subreddit(unique_name, 'The %s' % unique_name,
                                 description)
 
+    @local_only
+    def test_delete_redditor(self):
+        random_u = 'PyAPITestUser%d' % random.randint(3, 10240)
+        random_p = 'pass%d' % random.randint(3, 10240)
+        self.r.create_redditor(random_u, random_p)
+        self.r.login(random_u, random_p)
+        self.assertTrue(self.r.is_logged_in())
+        self.r.delete(random_p)
+        self.r.clear_authentication()
+        self.assertRaises(errors.InvalidUserPass, self.r.login, random_u,
+                          random_p)
+
+    @local_only
+    def test_delete_redditor_wrong_password(self):
+        random_u = 'PyAPITestUser%d' % random.randint(3, 10240)
+        random_p = 'pass%d' % random.randint(3, 10240)
+        self.r.create_redditor(random_u, random_p)
+        self.r.login(random_u, random_p)
+        self.assertTrue(self.r.is_logged_in())
+        self.assertRaises(errors.InvalidUserPass, self.r.delete, 'wxyz')
+
     @local_only
     def test_failed_feedback(self):
         self.assertRaises(errors.InvalidEmails, self.r.send_feedback,
@@ -1155,7 +1172,6 @@ class ModeratorSubredditTest(unittest.TestCase, AuthenticatedHelper):
         other = self.r.get_redditor(self.other_user_name)
         actions = list(self.subreddit.get_mod_log(mod=other.name))
         self.assertTrue(actions)
-        #self.assertTrue(all(x.mod_id36 == other.id for x in actions))
         self.assertTrue(all(x.mod.lower() == other.name.lower()
                             for x in actions))
 
@@ -1163,7 +1179,6 @@ class ModeratorSubredditTest(unittest.TestCase, AuthenticatedHelper):
         other = self.r.get_redditor(self.other_user_name)
         actions = list(self.subreddit.get_mod_log(mod=other))
         self.assertTrue(actions)
-        #self.assertTrue(all(x.mod_id36 == other.id for x in actions))
         self.assertTrue(all(x.mod.lower() == other.name.lower()
                             for x in actions))
 
@@ -1225,6 +1240,13 @@ class ModeratorUserTest(unittest.TestCase, AuthenticatedHelper):
         self.add_remove(self.subreddit.add_ban, self.subreddit.remove_ban,
                         self.subreddit.get_banned)
 
+    def test_get_banned_note(self):
+        # TODO: Update this test to add/update the ban note when ban note
+        # adding is supported.
+        params = {'user': self.other_non_mod_name}
+        data = next(self.subreddit.get_banned(user_only=False, params=params))
+        self.assertEqual(data['note'], 'no reason in particular 2')
+
     def test_contributors(self):
         self.add_remove(self.subreddit.add_contributor,
                         self.subreddit.remove_contributor,
@@ -1878,6 +1900,10 @@ class WikiTests(unittest.TestCase, BasicHelper):
         tmp = self.subreddit.get_wiki_page(result[0].page).content_md
         self.assertEqual(result[0].content_md, tmp)
 
+    def test_revision_by(self):
+        self.assertTrue(any(x.revision_by for x in
+                            self.subreddit.get_wiki_pages()))
+
 
 if __name__ == '__main__':
     unittest.main()
